pub struct DecoDepth {
pub min_fsw: u16,
pub max_fsw: u16,
pub rows: Vec<RowDeco>,
}Expand description
a depth in the air decompression table
Fields
min_fsw: u16the lower end of allowed depth for a specific profile in the air decompression tables expressed feet of sea water
max_fsw: u16the higher end of allowed depth for a specific profile in the air decompression tables expressed feet of sea water
rows: Vec<RowDeco>a row in a depth of the air decompression