pub struct Group {
pub group_letter: String,
pub min_time: u16,
pub max_time: u16,
}Expand description
A specific item in one of the rows of the US Navy air no-decompression table
Fields
group_letter: Stringthe repetitive group letter
min_time: u16the lower end of the timeframe for a specific row expressed in minutes
max_time: u16the higher end of the timeframe for a specific row expressed in minutes