pub struct Rnt {
pub min_depth: u16,
pub max_depth: u16,
pub rnt: u16,
}Expand description
item in the row of the table for residual nitrogen time
Fields
min_depth: u16the lower end of allowed depth for a specific RNT item expressed feet of sea water
max_depth: u16the higher end of allowed depth for a specific RNT item expressed feet of sea water
rnt: u16the residual nitrogen time expressed in minutes