pub struct RowNdl {
pub min_fsw: u16,
pub max_fsw: u16,
pub unlimited: bool,
pub no_stop_limit: u16,
pub values: Vec<Group>,
}Expand description
row in the air No Decompression table
Fields
min_fsw: u16the lower end of allowed depths for a specific row expressed in Feet of sea water
max_fsw: u16the higher end of allowed depths for a specific row expressed in Feet of sea water
unlimited: boolthe row has unlimited no-decompression limit? (usually no deeper than 30 Feet of sea water)
no_stop_limit: u16the no decompression limit expressed in minutes
values: Vec<Group>a specific item in one of the rows of the US Navy air no-decompression table