pub struct RowRgl {
pub group_letter: String,
pub min_time: u16,
pub max_time: u16,
pub repet_letter: String,
}Expand description
a row of the table for surface interval time and repetitive letter
Fields
group_letter: Stringgroup letter before the surface interval time
min_time: u16the lower end of allowed times for a specific row expressed in minutes
max_time: u16the higher end of allowed times for a specific row expressed in minutes
repet_letter: Stringgroup letter after the surface interval time