pub struct RowRnt {
pub repet_letter: String,
pub rnt: Vec<Rnt>,
}Expand description
a row in the table for residual nitrogen time
Fields
repet_letter: Stringthe repet group letter for the residual nitrogen time item
rnt: Vec<Rnt>item in the row of the table for residual nitrogen time