pub struct TableAirDeco {
pub table_code: String,
pub table_name: String,
pub table_data: Vec<DecoDepth>,
}Expand description
the air decompression table
Fields
table_code: Stringrepresents a unique id for a table within the diving-decompression project.
table_name: Stringoficially recognized name for a table beyond the diving-decompression project.
table_data: Vec<DecoDepth>table data