pub struct TableRgl {
pub table_code: String,
pub table_name: String,
pub table_data: Vec<RowRgl>,
}Expand description
the table for surface interval time and repetitive letter
Fields
table_code: Stringrepresents a unique id for a table within the diving-decompression project.
table_name: Stringoficially recognized name for a table beyond the diving-decompression project.
table_data: Vec<RowRgl>a row of the table for surface interval time and repetitive letter