pub struct TableRnt {
pub table_code: String,
pub table_name: String,
pub table_note_9981: String,
pub table_data: Vec<RowRnt>,
}Expand description
the table for residual nitrogen time
Fields
table_code: Stringrepresents a unique id for a table within the diving-decompression project.
table_name: Stringoficially recognized name for a table beyond the diving-decompression project.
table_note_9981: Stringa note displayed when the rnt exceeds the no decompression limit and the profile has an unlimited no decompression limit in the no decompression table for shallower depths as per the US Navy dive manual
table_data: Vec<RowRnt>a row in the table for residual nitrogen time